@@ -72,7 +72,7 @@ def setup_logging(
     formatter = "[%(asctime)s] app=" + prefix + " level=%(levelname)s msg=%(message)s"
 
     if logfile:
-        logdir = os.path.basename(logfile)
+        logdir = os.path.dirname(logfile)
 
         if not os.path.isdir(logdir):
             os.makedirs(logdir)
